pub struct GeneratorOutput {
pub dimension_type: DimensionTypeRef,
pub config: Value,
pub generator: ChunkGeneratorType,
pub is_flat: bool,
pub sea_level: i32,
}Expand description
Fully constructed generator metadata for a world.
Fields
dimension_type: DimensionTypeRefVanilla dimension type rules used by this loaded world.
config: ValueGenerator config after applying generator defaults.
generator: ChunkGeneratorTypeChunk generator instance.
is_flat: boolWhether the client should treat this as a flat world.
sea_level: i32Sea level sent in login/respawn packets.